Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(784)

Unified Diff: corelib/src/isolate.dart

Issue 8457005: convert isolates to use Future (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: updated co19 Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « corelib/src/future.dart ('k') | frog/lib/dom/html.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: corelib/src/isolate.dart
diff --git a/corelib/src/isolate.dart b/corelib/src/isolate.dart
index 54ec293eadffd2ab76c71314452c43814c25a34f..480e10c4ca73528a2ca7c80a473285e75bf114fd 100644
--- a/corelib/src/isolate.dart
+++ b/corelib/src/isolate.dart
@@ -137,14 +137,14 @@ class Isolate {
* During the initialization of the new isolate a [ReceivePort] is created
* inside the new isolate and stored in [port]. A corresponding
* [SendPort] is sent to the isolate that invoked [spawn]. Since spawning an
* isolate is an asynchronous operation this method returns a [Promise] of
* this [SendPort].
*
* A common pattern to instantiate new isolates is to enqueue the instructions
- * in [Promise.then].
+ * in [Future.then].
* [:myIsolate.spawn().then((SendPort port) { port.send('hi there'); });:]
*/
- Promise<SendPort> spawn() {
+ Future<SendPort> spawn() {
return IsolateNatives.spawn(this, _isLight);
}
« no previous file with comments | « corelib/src/future.dart ('k') | frog/lib/dom/html.dart » ('j') | no next file with comments »
@@ -137,14 +137,14 @@ class Isolate {
* inside the new isolate and stored in [port]. A corresponding
* [SendPort] is sent to the isolate that invoked [spawn]. Since spawning an
- * isolate is an asynchronous operation this method returns a [Promise] of
+ * isolate is an asynchronous operation this method returns a [Future] of
* this [SendPort].
*

Powered by Google App Engine
This is Rietveld 408576698